"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getVueSourceFile = exports.isRelativeVue = exports.isVue = exports.createLog = exports.resolveVueFile = exports.resolvePluginConfig = exports.resolvedCustomRelativeModule = exports.createFilter = void 0;
const tts = __importStar(require("typescript"));
const path_1 = __importDefault(require("path"));
const compiler_sfc_1 = require("@vue/compiler-sfc");
/** 根据配置生成匹配正则 */
function createFilter(roots, folders) {
    const rootsStr = roots.map((r) => {
        let res = r.name;
        for (let i = 0; i < r.depth; i++) {
            res += "/[^/]+";
        }
        return res;
    });
    return {
        fileFilter: new RegExp(`/(${rootsStr.join("|")})/`),
        importFilter: new RegExp(`^@/(${folders.join("|")})\\b`),
    };
}
exports.createFilter = createFilter;
/** 自解析模块缓存 */
const extensions = [".ts", ".tsx", ".js", ".jsx"];
const cache = {};
function resolvedCustomRelativeModule(ts, moduleName, containingFile, fileFilter) {
    const m = containingFile.match(fileFilter);
    const module = containingFile.slice(0, m.index + m[0].length) +
        moduleName.replace("@/", "");
    if (!cache[module]) {
        if (/\.vue$/.test(module)) {
            if (ts.sys.fileExists(module)) {
                cache[module] = {
                    resolvedFileName: module,
                    isExternalLibraryImport: false,
                    extension: ".d.ts",
                };
            }
        }
        else if (/\/$/.test(module)) {
            for (const ext of extensions) {
                if (ts.sys.fileExists(`${module}index${ext}`)) {
                    cache[module] = {
                        resolvedFileName: `${module}index${ext}`,
                        isExternalLibraryImport: false,
                        extension: /\.ts/.test(ext) ? ext : undefined,
                    };
                    break;
                }
            }
        }
        else {
            for (const ext of extensions) {
                if (ts.sys.fileExists(`${module}${ext}`)) {
                    cache[module] = {
                        resolvedFileName: `${module}${ext}`,
                        isExternalLibraryImport: false,
                        extension: /\.ts/.test(ext) ? ext : undefined,
                    };
                    break;
                }
            }
            if (!cache[module]) {
                for (const ext of extensions) {
                    if (ts.sys.fileExists(`${module}/index${ext}`)) {
                        cache[module] = {
                            resolvedFileName: `${module}/index${ext}`,
                            isExternalLibraryImport: false,
                            extension: /\.ts/.test(ext) ? ext : undefined,
                        };
                        break;
                    }
                }
            }
        }
    }
    return cache[module] || undefined;
}
exports.resolvedCustomRelativeModule = resolvedCustomRelativeModule;
function resolvePluginConfig(info) {
    // 根目录
    const roots = info.config.roots || [
        {
            name: "ACT",
            depth: 2,
        },
        {
            name: "COMMON",
            depth: 1,
        },
    ];
    // 相对目录
    const folders = info.config.folders || [
        "api",
        "components",
        "pages",
        "store",
        "img",
        "js",
        "style",
        "scripts",
    ];
    return { roots, folders };
}
exports.resolvePluginConfig = resolvePluginConfig;
/** 解析.vue文件路径 */
function resolveVueFile(name, containingFile, info) {
    if (isRelativeVue(name)) {
        return {
            extension: ".d.ts",
            isExternalLibraryImport: false,
            resolvedFileName: path_1.default.resolve(path_1.default.dirname(containingFile), name),
        };
    }
    return undefined;
}
exports.resolveVueFile = resolveVueFile;
/** 打印输出 */
function createLog(info) {
    return (...args) => {
        info.project.projectService.logger.info(args.map((arg) => String(arg)).join(" "));
    };
}
exports.createLog = createLog;
function isVue(file) {
    return /\.vue$/.test(file);
}
exports.isVue = isVue;
function isRelativeVue(file) {
    return isVue(file) && /^\.\.?($|[\\/])/.test(file);
}
exports.isRelativeVue = isRelativeVue;
function getVueSourceFile(filename, scriptSnapshot, log) {
    var _a, _b, _c, _d;
    const { descriptor } = (0, compiler_sfc_1.parse)(scriptSnapshot.getText(0, scriptSnapshot.getLength()), {
        filename,
    });
    let compiledScript = null;
    try {
        compiledScript = (0, compiler_sfc_1.compileScript)(descriptor, {
            id: filename,
            sourceMap: Boolean(((_b = (_a = descriptor.script) === null || _a === void 0 ? void 0 : _a.attrs) === null || _b === void 0 ? void 0 : _b.sourceMap) ||
                ((_d = (_c = descriptor.scriptSetup) === null || _c === void 0 ? void 0 : _c.attrs) === null || _d === void 0 ? void 0 : _d.sourceMap)),
        });
    }
    catch (e) { }
    // const scriptSnapshot = tts.ScriptSnapshot.fromString(descriptor.script.content);
    const sourceFile = tts.createSourceFile(filename, (compiledScript === null || compiledScript === void 0 ? void 0 : compiledScript.content) || "", tts.ScriptTarget.ESNext, true);
    sourceFile.isDeclarationFile = true;
    return sourceFile;
}
exports.getVueSourceFile = getVueSourceFile;
//# sourceMappingURL=utils.js.map